
WuttaMess
=========

This package provides various helpers for use with `Fabric
<https://www.fabfile.org>`_ automation.

It can be used to deploy custom apps built with the `Wutta framework
<https://wuttaproject.org>`_, but is not specific to that use case.
It can also be used for general server setup etc.

However it is only intended for use with Linux (and similar) for the
target machine.

Good documentation and 100% `test coverage`_ are priorities for this
project.

.. _test coverage: https://buildbot.rattailproject.org/coverage/wuttamess/


.. toctree::
   :maxdepth: 2
   :caption: Documentation:

   narr/install
   narr/usage

.. toctree::
   :maxdepth: 1
   :caption: Package API:

   api/wuttamess
   api/wuttamess.apt
   api/wuttamess.sync
